// src/components/Boxes.js
import React, { useEffect, useState } from 'react';
import { Container, Button, TextField, Table, TableBody, TableCell, TableContainer, TableHead, TableRow } from '@mui/material';
import { Delete as DeleteIcon } from '@mui/icons-material';
import { Link as RouterLink } from 'react-router-dom'; // Import Link from react-router-dom
import { PRIMARY_COLOR, SECONDARY_COLOR } from '../App';
import { api } from '../services/api';

export default function Boxes({ token }) {
  const [boxes, setBoxes] = useState([]);
  const [newBoxName, setNewBoxName] = useState('');

  useEffect(() => {
    fetchBoxes();
  }, [token]);

  const fetchBoxes = async () => {
    try {
      const response = await api.boxes.getAll(token);
      setBoxes(response.data);
    } catch (error) {
      console.error('Error fetching boxes:', error);
    }
  };

  const handleCreateBox = async () => {
    try {
      const response = await api.boxes.create(token, { name: newBoxName });
      setBoxes([...boxes, response.data]);
      setNewBoxName('');
    } catch (error) {
      console.error('Error creating box:', error);
    }
  };

  const handleDeleteBox = async (id) => {
    try {
      await api.boxes.delete(token, id);
      setBoxes(boxes.filter(box => box.ID !== id));
    } catch (error) {
      console.error('Error deleting box:', error);
    }
  };

  return (
    <Container>

      <TableContainer>
        <Table size="small">
          <TableHead>
            <TableRow>
              <TableCell>Box Name</TableCell>
              <TableCell>Actions</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {boxes.map((box) => (
              <TableRow key={box.ID}>
                <TableCell>
                  <RouterLink to={`/api/v1/boxes/${box.ID}/items`} state={{ boxName: box.name, boxID: box.ID }}>
                    {box.name}
                  </RouterLink>
                </TableCell>
                <TableCell>
                  <Button onClick={() => handleDeleteBox(box.ID)} startIcon={<DeleteIcon />}>
                    Delete
                  </Button>
                </TableCell>
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </TableContainer>
      <TextField
        label="New Box"
        variant="outlined"
        fullWidth
        value={newBoxName}
        onChange={(e) => setNewBoxName(e.target.value)}
      />
      <Button sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} variant="contained" color="primary" onClick={handleCreateBox}>
        Add Box
      </Button>
    </Container>
  );
}